
.. automodule:: bci_framework.framework.widgets
   :members:
   :no-undoc-members:
   :no-show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   bci_framework.framework.widgets.annotations
   bci_framework.framework.widgets.connection
   bci_framework.framework.widgets.montage
   bci_framework.framework.widgets.projects
   bci_framework.framework.widgets.records
